==> qcad-3.32.4.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Вертикальний/Горизонтальний</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Назад</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation type="unfinished">Нестандартний</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation type="unfinished">Сітка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished">Кінець</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished">Про суб&apos;єкта господарювання</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished">Перпендикулярний</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished">Тангенціальний</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished">Центр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished">Середній</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished">Перехрестя</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished">Посилання</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Відстань</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation type="unfinished">Недійсний</translation>
    </message>
</context>
</TS>

==> qcad-3.32.6.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Вертикальний/Горизонтальний</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Довільний</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Сітка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Кінцева точка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>На об&apos;єкті</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Перпендикуляр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Дотична</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Центр</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Середина</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Перетин</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Базова точка</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Відстань</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Недійсне</translation>
    </message>
</context>
</TS>
